Module beamlit.models.policy_location
=====================================

Classes
-------

`PolicyLocation(name: beamlit.types.Unset | str = <beamlit.types.Unset object>, type_: beamlit.types.Unset | str = <beamlit.types.Unset object>)`
:   Policy location
    
    Attributes:
        name (Union[Unset, str]): Policy location name
        type_ (Union[Unset, str]): Policy location type
    
    Method generated by attrs for class PolicyLocation.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `name: beamlit.types.Unset | str`
    :

    `type_: beamlit.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :